@@ -400,7 +400,7 @@ class Being notfinal : public ActorSprite,
         /**
          * Gets the way the monster blocks pathfinding for other objects
          */
-        BlockType::BlockType getBlockType() const override A_WARN_UNUSED
+        BlockTypeT getBlockType() const override A_WARN_UNUSED
         {
             if (!mInfo)
                 return BlockType::NONE;
@@ -895,6 +895,10 @@ class Being notfinal : public ActorSprite,
 
         void setRiding(const bool b) override final;
 
+        void setHorse(const int horseId);
+
+        void removeHorse();
+
         void setSellBoard(const std::string &text);
 
         std::string getSellBoard() const A_WARN_UNUSED
@@ -1086,8 +1090,9 @@ class Being notfinal : public ActorSprite,
 #ifdef EATHENA_SUPPORT
         ChatObject *mChat;
         HorseInfo *mHorseInfo;
+        std::vector<AnimatedSprite*> mDownHorseSprites;
+        std::vector<AnimatedSprite*> mUpHorseSprites;
 #endif
-        AnimatedSprite *mHorseSprite;
 
         int mX;             // position in tiles
         int mY;             // position in tiles
