@@ -23,6 +23,8 @@
 #ifndef GUI_WIDGETS_SELLDIALOG_H
 #define GUI_WIDGETS_SELLDIALOG_H
 
+#include "enums/simpletypes/itemcolor.h"
+
 #include "gui/widgets/window.h"
 
 #include "listeners/actionlistener.h"
@@ -92,7 +94,7 @@ class SellDialog notfinal : public Window,
 
         void addItem(const int id,
                      const int type,
-                     const unsigned char color,
+                     const ItemColor color,
                      const int amount,
                      const int price);
 
@@ -123,17 +125,17 @@ class SellDialog notfinal : public Window,
         virtual void initButtons()
         { }
 
-        Button *mSellButton;
-        Button *mQuitButton;
+        Button *mSellButton A_NONNULLPOINTER;
+        Button *mQuitButton A_NONNULLPOINTER;
         Button *mAddMaxButton;
         Button *mIncreaseButton;
         Button *mDecreaseButton;
-        ShopListBox *mShopItemList;
-        ScrollArea *mScrollArea;
+        ShopListBox *mShopItemList A_NONNULLPOINTER;
+        ScrollArea *mScrollArea A_NONNULLPOINTER;
         Label *mMoneyLabel;
         Label *mQuantityLabel;
         Slider *mSlider;
-        ShopItems *mShopItems;
+        ShopItems *mShopItems A_NONNULLPOINTER;
 
         int mPlayerMoney;
         int mMaxItems;
