@@ -30,7 +30,6 @@
 
 #include "gui/widgets/createwidget.h"
 #include "gui/widgets/listbox.h"
-#include "gui/widgets/skilldata.h"
 
 #include "gui/fonts/font.h"
 
@@ -38,8 +37,6 @@
 
 #include "gui/popups/skillpopup.h"
 
-#include "render/graphics.h"
-
 #include "utils/delete2.h"
 
 #include "resources/skillconsts.h"
@@ -90,7 +87,7 @@ class SkillListBox final : public ListBox
             return static_cast<SkillModel*>(mListModel)->getSkillAt(selected);
         }
 
-        void draw(Graphics *graphics) override final
+        void draw(Graphics *graphics) override final A_NONNULL(2)
         {
             if (!mListModel)
                 return;
@@ -174,7 +171,7 @@ class SkillListBox final : public ListBox
             }
         }
 
-        void safeDraw(Graphics *graphics) override final
+        void safeDraw(Graphics *graphics) override final A_NONNULL(2)
         {
             SkillListBox::draw(graphics);
         }
