@@ -266,7 +266,7 @@ Setup_Chat::Setup_Chat(const Widget2 *const widget) :
     new SetupItemTextField(_("Highlight words (separated by comma)"),
         _("Here you can specify some extra words which will also cause "
         "highlighting. Use comma to separate words.\n\nNote: frequent "
-        "hilights are annoying - use it with caution."),
+        "highlights are annoying - use it with caution."),
         "highlightWords", this, "highlightWordsEvent");
 
     // TRANSLATORS: settings option
