@@ -51,14 +51,14 @@ Setup_Joystick::Setup_Joystick(const Widget2 *const widget) :
     mCalibrateButton(new Button(this, _("Calibrate"), "calibrate", this)),
     // TRANSLATORS: joystick settings tab button
     mDetectButton(new Button(this, _("Detect joysticks"), "detect", this)),
-    mOriginalJoystickEnabled(config.getBoolValue("joystickEnabled")),
     // TRANSLATORS: joystick settings tab checkbox
     mJoystickEnabled(new CheckBox(this, _("Enable joystick"))),
     mNamesModel(new NamesModel),
     mNamesDropDown(new DropDown(this, mNamesModel)),
     // TRANSLATORS: joystick settings tab checkbox
     mUseInactiveCheckBox(new CheckBox(this, _("Use joystick if client "
-        "window inactive"), config.getBoolValue("useInactiveJoystick")))
+        "window inactive"), config.getBoolValue("useInactiveJoystick"))),
+    mOriginalJoystickEnabled(config.getBoolValue("joystickEnabled"))
 {
     // TRANSLATORS: joystick settings tab name
     setName(_("Joystick"));
