@@ -116,7 +116,7 @@ Setup_Other::Setup_Other(const Widget2 *const widget) :
         "targetOnlyReachable", this, "targetOnlyReachableEvent");
 
     // TRANSLATORS: settings option
-    new SetupItemCheckBox(_("Seleck auto target for attack skills"), "",
+    new SetupItemCheckBox(_("Select auto target for attack skills"), "",
         "skillAutotarget", this, "skillAutotargetEvent");
 
     // TRANSLATORS: settings option
