@@ -138,7 +138,8 @@ void MailEditWindow::action(const ActionEvent &event)
             const Inventory *const inv = PlayerInfo::getInventory();
             if (inv)
             {
-                const Item *const item = inv->findItem(tempItem->getId(), 1);
+                const Item *const item = inv->findItem(
+                    tempItem->getId(), ItemColor_one);
                 if (item)
                 {
                     mailHandler->setAttach(item->getInvIndex(),
@@ -147,8 +148,14 @@ void MailEditWindow::action(const ActionEvent &event)
             }
         }
 
+        std::string subject = mSubjectField->getText();
+        if (subject.empty())
+        {
+            // TRANSLATORS: empty mail message subject
+            subject.append(_("empty subject"));
+        }
         mailHandler->send(mToField->getText(),
-            mSubjectField->getText(),
+            subject,
             mMessageField->getText());
     }
     else if (eventId == "add")
@@ -194,3 +201,8 @@ void MailEditWindow::setMessage(const std::string &str)
 {
     mMessageField->setText(str);
 }
+
+void MailEditWindow::close()
+{
+    scheduleDelete();
+}
