@@ -107,11 +107,12 @@ MailViewWindow::MailViewWindow(const MailMessage *const message) :
     placer(0, n++, mMessageLabel);
     if (message->itemId)
     {
-        ResourceManager *const resman = ResourceManager::getInstance();
         const ItemInfo &item = ItemDB::get(message->itemId);
-        Image *const image = resman->getImage(combineDye2(
+        // +++ need use message->cards and ItemColorManager for colors
+        Image *const image = resourceManager->getImage(combineDye2(
             paths.getStringValue("itemIcons").append(
-            item.getDisplay().image), item.getDyeColorsString(1)));
+            item.getDisplay().image),
+            item.getDyeIconColorsString(ItemColor_one)));
 
         mIcon = new Icon(this, image);
         if (message->itemAmount != 1)
