@@ -21,6 +21,8 @@
 #ifndef LISTENERS_VENDINGMODELISTENER_H
 #define LISTENERS_VENDINGMODELISTENER_H
 
+#ifdef EATHENA_SUPPORT
+
 #include "listeners/baselistener.hpp"
 
 #include "localconsts.h"
@@ -35,4 +37,5 @@ class VendingModeListener notfinal
     defineListenerHeader(VendingModeListener)
 };
 
+#endif  // EATHENA_SUPPORT
 #endif  // LISTENERS_VENDINGMODELISTENER_H
