@@ -22,15 +22,9 @@
 
 #include "net/ea/adminhandler.h"
 
-#include "notifymanager.h"
-
-#include "enums/resources/notifytypes.h"
-
 #include "gui/chatconsts.h"
 
 #include "net/chathandler.h"
-#include "net/messagein.h"
-#include "net/serverfeatures.h"
 
 #include "utils/stringutils.h"
 
@@ -74,27 +68,12 @@ void AdminHandler::ipcheckName(const std::string &name) const
     chatHandler->talk("@ipcheck " + name, GENERAL_CHANNEL);
 }
 
-void AdminHandler::createItems(const int id, const int color,
+void AdminHandler::createItems(const int id,
+                               const ItemColor color A_UNUSED,
                                const int amount) const
 {
-    if (!serverFeatures->haveItemColors())
-    {
-        chatHandler->talk(strprintf("@item %d %d",
-            id, amount), GENERAL_CHANNEL);
-    }
-    else
-    {
-        chatHandler->talk(strprintf("@item %d %d %d",
-            id, color, amount), GENERAL_CHANNEL);
-    }
-}
-
-void AdminHandler::processKickAck(Net::MessageIn &msg)
-{
-    if (msg.readInt32("flag") == 0)
-        NotifyManager::notify(NotifyTypes::KICK_FAIL);
-    else
-        NotifyManager::notify(NotifyTypes::KICK_SUCCEED);
+    chatHandler->talk(strprintf("@item %d %d", id, amount),
+        GENERAL_CHANNEL);
 }
 
 }  // namespace Ea
