@@ -23,13 +23,17 @@
 #include "net/ea/beingrecv.h"
 
 #include "actormanager.h"
+#include "configuration.h"
 #include "game.h"
+#include "notifymanager.h"
 #include "party.h"
 
 #include "being/localplayer.h"
 #include "being/playerrelation.h"
 #include "being/playerrelations.h"
 
+#include "enums/resources/notifytypes.h"
+
 #include "enums/resources/map/mapitemtype.h"
 
 #include "gui/viewport.h"
@@ -64,10 +68,10 @@ void BeingRecv::processBeingRemove(Net::MessageIn &msg)
     // A being should be removed or has died
 
     const BeingId id = msg.readBeingId("being id");
+    const uint8_t type = msg.readUInt8("remove flag");
     Being *const dstBeing = actorManager->findBeing(id);
     if (!dstBeing)
     {
-        msg.readUInt8("dead flag?");
         BLOCK_END("BeingRecv::processBeingRemove")
         return;
     }
@@ -79,7 +83,7 @@ void BeingRecv::processBeingRemove(Net::MessageIn &msg)
     if (dstBeing == localPlayer->getTarget())
         localPlayer->stopAttack(true);
 
-    if (msg.readUInt8("dead flag?") == 1U)
+    if (type == 1U)
     {
         if (dstBeing->getCurrentAction() != BeingAction::DEAD)
         {
@@ -87,12 +91,52 @@ void BeingRecv::processBeingRemove(Net::MessageIn &msg)
             dstBeing->recalcSpritesOrder();
         }
     }
+    else if (type == 0U && dstBeing->getType() == ActorType::Npc)
+    {
+        const BeingInfo *const info = dstBeing->getInfo();
+        if (!info || info->getAllowDelete())
+            actorManager->destroy(dstBeing);
+    }
     else
     {
         if (dstBeing->getType() == ActorType::Player)
         {
             if (socialWindow)
                 socialWindow->updateActiveList();
+            const std::string name = dstBeing->getName();
+            if (!name.empty() && config.getBoolValue("logPlayerActions"))
+            {
+                switch (type)
+                {
+                    case 0:
+                        break;
+                    case 1:
+                        NotifyManager::notify(
+                            NotifyTypes::BEING_REMOVE_DIED,
+                            name);
+                        break;
+                    case 2:
+                        NotifyManager::notify(
+                            NotifyTypes::BEING_REMOVE_LOGGED_OUT,
+                            name);
+                        break;
+                    case 3:
+                        NotifyManager::notify(
+                            NotifyTypes::BEING_REMOVE_WARPED,
+                            name);
+                        break;
+                    case 4:
+                        NotifyManager::notify(
+                            NotifyTypes::BEING_REMOVE_TRICK_DEAD,
+                            name);
+                        break;
+                    default:
+                        NotifyManager::notify(
+                            NotifyTypes::BEING_REMOVE_UNKNOWN,
+                            name);
+                        break;
+                }
+            }
         }
         actorManager->destroy(dstBeing);
     }
