@@ -31,11 +31,6 @@ class LoginData;
 
 struct Token;
 
-namespace Net
-{
-    class MessageIn;
-}
-
 namespace Ea
 {
 
@@ -70,8 +65,7 @@ class LoginHandler notfinal : public Net::LoginHandler
 
         virtual ServerInfo *getCharServer() const A_WARN_UNUSED = 0;
 
-        const Token &getToken() const A_WARN_UNUSED
-        { return mToken; }
+        const Token &getToken() const A_WARN_UNUSED;
 
         void logout() const override final;
 
@@ -81,12 +75,6 @@ class LoginHandler notfinal : public Net::LoginHandler
                                const std::string &password)
                                const override final;
 
-        static void processUpdateHost(Net::MessageIn &msg);
-
-        static void processLoginData(Net::MessageIn &msg);
-
-        static void processLoginError(Net::MessageIn &msg);
-
         void loginOrRegister(LoginData *const data) const override final;
 
     protected:
@@ -95,12 +83,6 @@ class LoginHandler notfinal : public Net::LoginHandler
         virtual void sendLoginRegister(const std::string &username,
                                        const std::string &password,
                                        const std::string &email) const = 0;
-
-        static std::string mUpdateHost;
-        static Worlds mWorlds;
-        static Token mToken;
-        static bool mVersionResponse;
-        static bool mRegistrationEnabled;
 };
 
 }  // namespace Ea
