@@ -60,25 +60,6 @@ class PlayerHandler notfinal : public Net::PlayerHandler
                      const int base,
                      const int mod,
                      const Notify notify) const override;
-
-        static const int NoStat = INT_MAX;
-
-    protected:
-        static void processPlayerWarp(Net::MessageIn &msg);
-
-        static void processPlayerStatUpdate1(Net::MessageIn &msg);
-
-        static void processPlayerStatUpdate2(Net::MessageIn &msg);
-
-        static void processPlayerStatUpdate3(Net::MessageIn &msg);
-
-        static void processPlayerStatUpdate4(Net::MessageIn &msg);
-
-        static void processPlayerStatUpdate6(Net::MessageIn &msg);
-
-        static void processPlayerArrowMessage(Net::MessageIn &msg);
-
-        static void processMapMusic(Net::MessageIn &msg);
 };
 
 }  // namespace Ea
