@@ -25,20 +25,15 @@
 
 #include "net/battlegroundhandler.h"
 
-#include "net/eathena/messagehandler.h"
-
 namespace EAthena
 {
-class BattleGroundHandler final : public MessageHandler,
-                                  public Net::BattleGroundHandler
+class BattleGroundHandler final : public Net::BattleGroundHandler
 {
     public:
         BattleGroundHandler();
 
         A_DELETE_COPY(BattleGroundHandler)
 
-        void handleMessage(Net::MessageIn &msg) override final;
-
         void registerBg(const BattleGroundTypeT &type,
                         const std::string &name) const override final;
 
@@ -49,23 +44,6 @@ class BattleGroundHandler final : public MessageHandler,
                       const std::string &gameName) const override final;
 
         void checkState(const std::string &name) const override final;
-
-    protected:
-        void processBattleEmblem(Net::MessageIn &msg);
-
-        void processBattleUpdateScore(Net::MessageIn &msg);
-
-        void processBattleUpdateCoords(Net::MessageIn &msg);
-
-        void processBattlePlay(Net::MessageIn &msg);
-
-        void processBattleQueueAck(Net::MessageIn &msg);
-
-        void processBattleBegins(Net::MessageIn &msg);
-
-        void processBattleNoticeDelete(Net::MessageIn &msg);
-
-        void processBattleJoined(Net::MessageIn &msg);
 };
 
 }  // namespace EAthena
