@@ -261,9 +261,8 @@ void BeingRecv::processBeingVisible(Net::MessageIn &msg)
     int16_t speed = msg.readInt16("speed");
     const uint16_t stunMode = msg.readInt16("opt1");
     // probably wrong effect usage
-    const uint32_t statusEffects = msg.readInt16("opt2");
-    msg.readInt32("option");
-
+    uint32_t statusEffects = msg.readInt16("opt2");
+    statusEffects |= (static_cast<uint32_t>(msg.readInt32("option"))) << 16;
     const int16_t job = msg.readInt16("class");
 
     Being *dstBeing = actorManager->findBeing(id);
@@ -423,7 +422,7 @@ void BeingRecv::processBeingMove(Net::MessageIn &msg)
 //    {
         const uint16_t stunMode = msg.readInt16("opt1");
         // probably wrong effect usage
-        const uint32_t statusEffects = msg.readInt16("opt2");
+        uint32_t statusEffects = msg.readInt16("opt2");
 //    }
 //    else
 //    {
@@ -431,8 +430,7 @@ void BeingRecv::processBeingMove(Net::MessageIn &msg)
 //        msg.readInt16("body state");
 //        msg.readInt16("health state");
 //    }
-    msg.readInt32("effect state");
-
+    statusEffects |= (static_cast<uint32_t>(msg.readInt32("option"))) << 16;
     const int16_t job = msg.readInt16("class");
 
     Being *dstBeing = actorManager->findBeing(id);
@@ -594,7 +592,7 @@ void BeingRecv::processBeingSpawn(Net::MessageIn &msg)
 //    {
         const uint16_t stunMode = msg.readInt16("opt1");
         // probably wrong effect usage
-        const uint32_t statusEffects = msg.readInt16("opt2");
+        uint32_t statusEffects = msg.readInt16("opt2");
 //    }
 //    else
 //    {
@@ -602,8 +600,7 @@ void BeingRecv::processBeingSpawn(Net::MessageIn &msg)
 //        msg.readInt16("body state");
 //        msg.readInt16("health state");
 //    }
-    msg.readInt32("effect state");
-
+    statusEffects |= (static_cast<uint32_t>(msg.readInt32("option"))) << 16;
     const int16_t job = msg.readInt16("class");
 
     Being *dstBeing = actorManager->findBeing(id);
@@ -1179,7 +1176,7 @@ void BeingRecv::processPlaterStatusChange(Net::MessageIn &msg)
 
     const uint16_t stunMode = msg.readInt16("stun mode");
     uint32_t statusEffects = msg.readInt16("status effect");
-    statusEffects |= (static_cast<uint32_t>(msg.readInt32("opt?"))) << 16;
+    statusEffects |= (static_cast<uint32_t>(msg.readInt32("option"))) << 16;
     dstBeing->setKarma(msg.readUInt8("karma"));
 
     dstBeing->setStunMode(stunMode);
@@ -1195,6 +1192,8 @@ void BeingRecv::processPlaterStatusChange2(Net::MessageIn &msg)
     if (!actorManager)
         return;
 
+    // look like this function unused on server
+
     const BeingId id = msg.readBeingId("account id");
     Being *const dstBeing = actorManager->findBeing(id);
     if (!dstBeing)
@@ -1364,21 +1363,35 @@ void BeingRecv::processBeingAttrs(Net::MessageIn &msg)
     const int len = msg.readInt16("len");
     if (len < 12)
         return;
+    const bool haveMount = serverFeatures->haveExtendedRiding();
+    if (haveMount && len < 14)
+        return;
+
     Being *const dstBeing = actorManager->findBeing(
         msg.readBeingId("player id"));
     const int gmLevel = msg.readInt32("gm level");
-    if (dstBeing && gmLevel)
+    uint16_t mount = 0;
+    if (haveMount)
+        mount = msg.readInt16("mount");
+    if (dstBeing)
     {
-        if (dstBeing == localPlayer)
-            localPlayer->setGMLevel(gmLevel);
-        dstBeing->setGM(true);
+        if (gmLevel)
+        {
+            if (dstBeing == localPlayer)
+                localPlayer->setGMLevel(gmLevel);
+            dstBeing->setGM(true);
+        }
+        else
+        {
+            if (dstBeing == localPlayer)
+                localPlayer->setGMLevel(0);
+            if (dstBeing)
+                dstBeing->setGM(false);
+        }
     }
-    else
+    if (haveMount)
     {
-        if (dstBeing == localPlayer)
-            localPlayer->setGMLevel(0);
-        if (dstBeing)
-            dstBeing->setGM(false);
+        dstBeing->setHorse(mount);
     }
 }
 
