@@ -23,35 +23,22 @@
 
 #include "net/markethandler.h"
 
-#include "net/eathena/messagehandler.h"
-
-class BuyDialog;
-
 namespace EAthena
 {
-class MarketHandler final : public MessageHandler,
-                            public Net::MarketHandler
+
+class MarketHandler final : public Net::MarketHandler
 {
     public:
         MarketHandler();
 
         A_DELETE_COPY(MarketHandler)
 
-        void handleMessage(Net::MessageIn &msg) override final;
-
         void close() override final;
 
         void buyItem(const int itemId,
                      const int type,
-                     const unsigned char color,
+                     const ItemColor color,
                      const int amount) const override final;
-
-    protected:
-        static void processMarketOpen(Net::MessageIn &msg);
-
-        static void processMarketBuyAck(Net::MessageIn &msg);
-
-        static BuyDialog *mBuyDialog;
 };
 
 }  // namespace EAthena
