@@ -22,18 +22,19 @@
 
 #include "net/eathena/npchandler.h"
 
-#include "actormanager.h"
-
 #include "being/localplayer.h"
 
 #include "gui/windows/npcdialog.h"
 
 #include "gui/widgets/createwidget.h"
 
-#include "net/eathena/messageout.h"
-#include "net/eathena/protocol.h"
+#include "net/messagein.h"
 
 #include "net/ea/eaprotocol.h"
+#include "net/ea/npcrecv.h"
+
+#include "net/eathena/messageout.h"
+#include "net/eathena/protocolout.h"
 
 #include "debug.h"
 
@@ -43,103 +44,11 @@ namespace EAthena
 {
 
 NpcHandler::NpcHandler() :
-    MessageHandler(),
     Ea::NpcHandler()
 {
-    static const uint16_t _messages[] =
-    {
-        SMSG_NPC_CHOICE,
-        SMSG_NPC_MESSAGE,
-        SMSG_NPC_NEXT,
-        SMSG_NPC_CLOSE,
-        SMSG_NPC_INT_INPUT,
-        SMSG_NPC_STR_INPUT,
-        SMSG_NPC_CUTIN,
-        SMSG_NPC_VIEWPOINT,
-        SMSG_NPC_SHOW_PROGRESS_BAR,
-        SMSG_NPC_CLOSE_TIMEOUT,
-        SMSG_NPC_COMMAND,
-        SMSG_NPC_CHANGETITLE,
-        SMSG_NPC_AREA,
-        SMSG_NPC_SHOW_DIGIT,
-        SMSG_NPC_PROGRESS_BAR_ABORT,
-        0
-    };
-    handledMessages = _messages;
     npcHandler = this;
 }
 
-void NpcHandler::handleMessage(Net::MessageIn &msg)
-{
-    switch (msg.getId())
-    {
-        case SMSG_NPC_CHOICE:
-            processNpcChoice(msg);
-            break;
-
-        case SMSG_NPC_MESSAGE:
-            processNpcMessage(msg);
-            break;
-
-        case SMSG_NPC_CLOSE:
-            processNpcClose(msg);
-            break;
-
-        case SMSG_NPC_NEXT:
-            processNpcNext(msg);
-            break;
-
-        case SMSG_NPC_INT_INPUT:
-            processNpcIntInput(msg);
-            break;
-
-        case SMSG_NPC_STR_INPUT:
-            processNpcStrInput(msg);
-            break;
-
-        case SMSG_NPC_CUTIN:
-            processNpcCutin(msg);
-            break;
-
-        case SMSG_NPC_VIEWPOINT:
-            processNpcViewPoint(msg);
-            break;
-
-        case SMSG_NPC_SHOW_PROGRESS_BAR:
-            processNpcShowProgressBar(msg);
-            break;
-
-        case SMSG_NPC_CLOSE_TIMEOUT:
-            processNpcCloseTimeout(msg);
-            break;
-
-        case SMSG_NPC_COMMAND:
-            processNpcCommand(msg);
-            break;
-
-        case SMSG_NPC_CHANGETITLE:
-            processChangeTitle(msg);
-            break;
-
-        case SMSG_NPC_AREA:
-            processArea(msg);
-            break;
-
-        case SMSG_NPC_SHOW_DIGIT:
-            processShowDigit(msg);
-            break;
-
-        case SMSG_NPC_PROGRESS_BAR_ABORT:
-            processProgressBarAbort(msg);
-            break;
-
-        default:
-            break;
-    }
-
-    mDialog = nullptr;
-}
-
 void NpcHandler::talk(const BeingId npcId) const
 {
     createOutPacket(CMSG_NPC_TALK);
@@ -164,8 +73,8 @@ void NpcHandler::closeDialog(const BeingId npcId)
         NpcDialog *const dialog = (*it).second;
         if (dialog)
             dialog->close();
-        if (dialog == mDialog)
-            mDialog = nullptr;
+        if (dialog == Ea::NpcRecv::mDialog)
+            Ea::NpcRecv::mDialog = nullptr;
         NpcDialog::mNpcDialogs.erase(it);
     }
 }
@@ -212,7 +121,7 @@ void NpcHandler::sell(const BeingId beingId) const
 
 void NpcHandler::buyItem(const BeingId beingId A_UNUSED,
                          const int itemId,
-                         const unsigned char color A_UNUSED,
+                         const ItemColor color A_UNUSED,
                          const int amount) const
 {
     createOutPacket(CMSG_NPC_BUY_REQUEST);
@@ -286,120 +195,46 @@ void NpcHandler::selectAutoSpell(const int skillId) const
     outMsg.writeInt32(static_cast<int16_t>(skillId), "skill id");
 }
 
-BeingId NpcHandler::getNpc(Net::MessageIn &msg)
+BeingId NpcHandler::getNpc(Net::MessageIn &msg,
+                           const NpcActionT action)
 {
-    if (msg.getId() == SMSG_NPC_CHOICE
-        || msg.getId() == SMSG_NPC_MESSAGE
-        || msg.getId() == SMSG_NPC_CHANGETITLE)
-    {
-        msg.readInt16("len");
-    }
-
     const BeingId npcId = msg.readBeingId("npc id");
 
     const NpcDialogs::const_iterator diag = NpcDialog::mNpcDialogs.find(npcId);
-    mDialog = nullptr;
-
-    if (msg.getId() == SMSG_NPC_VIEWPOINT)
-        return npcId;
+    Ea::NpcRecv::mDialog = nullptr;
 
     if (diag == NpcDialog::mNpcDialogs.end())
     {
         // Empty dialogs don't help
-        if (msg.getId() == SMSG_NPC_CLOSE)
+        if (action == NpcAction::Close)
         {
             closeDialog(npcId);
             return npcId;
         }
-        else if (msg.getId() == SMSG_NPC_NEXT)
+        else if (action == NpcAction::Next)
         {
             nextDialog(npcId);
             return npcId;
         }
         else
         {
-            CREATEWIDGETV(mDialog, NpcDialog, npcId);
-            mDialog->saveCamera();
+            CREATEWIDGETV(Ea::NpcRecv::mDialog, NpcDialog, npcId);
+            Ea::NpcRecv::mDialog->saveCamera();
             if (localPlayer)
                 localPlayer->stopWalking(false);
-            NpcDialog::mNpcDialogs[npcId] = mDialog;
+            NpcDialog::mNpcDialogs[npcId] = Ea::NpcRecv::mDialog;
         }
     }
     else
     {
         NpcDialog *const dialog = diag->second;
-        if (mDialog && mDialog != dialog)
-            mDialog->restoreCamera();
-        mDialog = dialog;
-        if (mDialog)
-            mDialog->saveCamera();
+        if (Ea::NpcRecv::mDialog && Ea::NpcRecv::mDialog != dialog)
+            Ea::NpcRecv::mDialog->restoreCamera();
+        Ea::NpcRecv::mDialog = dialog;
+        if (Ea::NpcRecv::mDialog)
+            Ea::NpcRecv::mDialog->saveCamera();
     }
     return npcId;
 }
 
-void NpcHandler::processNpcCutin(Net::MessageIn &msg)
-{
-    UNIMPLIMENTEDPACKET;
-    mRequestLang = false;
-    msg.readString(64, "image name");
-    msg.readUInt8("type");
-}
-
-void NpcHandler::processNpcViewPoint(Net::MessageIn &msg)
-{
-    UNIMPLIMENTEDPACKET;
-    mRequestLang = false;
-    // +++ probably need add nav point and start moving to it
-    msg.readInt32("npc id");
-    msg.readInt32("type");  // 0 display for 15 sec,
-                            // 1 display until teleport,
-                            // 2 remove
-    msg.readInt32("x");
-    msg.readInt32("y");
-    msg.readUInt8("number");  // can be used for scripts
-    msg.readInt32("color");
-}
-
-void NpcHandler::processNpcShowProgressBar(Net::MessageIn &msg)
-{
-    UNIMPLIMENTEDPACKET;
-    mRequestLang = false;
-    // +++ probably need show progress bar in npc dialog
-    msg.readInt32("color");
-    msg.readInt32("seconds");
-}
-
-void NpcHandler::processNpcCloseTimeout(Net::MessageIn &msg)
-{
-    UNIMPLIMENTEDPACKET;
-    mRequestLang = false;
-    // this packet send after npc closed by timeout.
-    msg.readInt32("npc id");
-}
-
-void NpcHandler::processArea(Net::MessageIn &msg)
-{
-    const int len = msg.readInt16("len");
-    if (len < 12)
-        return;
-    Being *const dstBeing = actorManager->findBeing(
-        msg.readBeingId("npc id"));
-    const int area = msg.readInt32("area size");
-    if (dstBeing)
-        dstBeing->setAreaSize(area);
-}
-
-void NpcHandler::processShowDigit(Net::MessageIn &msg)
-{
-    UNIMPLIMENTEDPACKET;
-
-    msg.readUInt8("type");
-    msg.readInt32("value");
-}
-
-void NpcHandler::processProgressBarAbort(Net::MessageIn &msg)
-{
-    UNIMPLIMENTEDPACKET;
-}
-
 }  // namespace EAthena
