@@ -25,20 +25,16 @@
 
 #include "net/ea/npchandler.h"
 
-#include "net/eathena/messagehandler.h"
-
 namespace EAthena
 {
 
-class NpcHandler final : public MessageHandler, public Ea::NpcHandler
+class NpcHandler final : public Ea::NpcHandler
 {
     public:
         NpcHandler();
 
         A_DELETE_COPY(NpcHandler)
 
-        void handleMessage(Net::MessageIn &msg) override final;
-
         void talk(const BeingId npcId) const override final;
 
         void nextDialog(const BeingId npcId) const override final;
@@ -60,7 +56,7 @@ class NpcHandler final : public MessageHandler, public Ea::NpcHandler
 
         void buyItem(const BeingId beingId,
                      const int itemId,
-                     const unsigned char color,
+                     const ItemColor color,
                      const int amount) const override final;
 
         void sellItem(const BeingId beingId,
@@ -81,28 +77,14 @@ class NpcHandler final : public MessageHandler, public Ea::NpcHandler
 
         void refine(const int index) const override final;
 
-        BeingId getNpc(Net::MessageIn &msg) override final;
+        BeingId getNpc(Net::MessageIn &msg,
+                       const NpcActionT action) override final;
 
         void identify(const int index) const override final;
 
         void selectArrow(const int nameId) const override final;
 
         void selectAutoSpell(const int skillId) const override final;
-
-    protected:
-        static void processNpcCutin(Net::MessageIn &msg);
-
-        static void processNpcViewPoint(Net::MessageIn &msg);
-
-        static void processNpcShowProgressBar(Net::MessageIn &msg);
-
-        static void processNpcCloseTimeout(Net::MessageIn &msg);
-
-        static void processArea(Net::MessageIn &msg);
-
-        static void processShowDigit(Net::MessageIn &msg);
-
-        static void processProgressBarAbort(Net::MessageIn &msg);
 };
 
 }  // namespace EAthena
