@@ -23,20 +23,15 @@
 
 #include "net/searchstorehandler.h"
 
-#include "net/eathena/messagehandler.h"
-
 namespace EAthena
 {
-class SearchStoreHandler final : public MessageHandler,
-                                 public Net::SearchStoreHandler
+class SearchStoreHandler final : public Net::SearchStoreHandler
 {
     public:
         SearchStoreHandler();
 
         A_DELETE_COPY(SearchStoreHandler)
 
-        void handleMessage(Net::MessageIn &msg) override final;
-
         void search(const StoreSearchTypeT type,
                     const int minPrice,
                     const int maxPrice,
@@ -49,15 +44,6 @@ class SearchStoreHandler final : public MessageHandler,
         void select(const int accountId,
                     const int storeId,
                     const int itemId) const override final;
-
-    protected:
-        static void processSearchAck(Net::MessageIn &msg);
-
-        static void processSearchFailed(Net::MessageIn &msg);
-
-        static void processSearchOpen(Net::MessageIn &msg);
-
-        static void processSearchClickAck(Net::MessageIn &msg);
 };
 
 }  // namespace EAthena
