@@ -23,6 +23,8 @@
 
 #ifdef EATHENA_SUPPORT
 
+#include "enums/simpletypes/itemcolor.h"
+
 #include <string>
 
 #include "localconsts.h"
@@ -40,7 +42,7 @@ class MarketHandler notfinal
 
         virtual void buyItem(const int itemId,
                              const int type,
-                             const unsigned char color,
+                             const ItemColor color,
                              const int amount) const = 0;
 };
 
