@@ -25,21 +25,17 @@
 
 #include "net/ea/chathandler.h"
 
-#include "net/tmwa/messagehandler.h"
-
 namespace TmwAthena
 {
 class MessageOut;
 
-class ChatHandler final : public MessageHandler, public Ea::ChatHandler
+class ChatHandler final : public Ea::ChatHandler
 {
     public:
         ChatHandler();
 
         A_DELETE_COPY(ChatHandler)
 
-        void handleMessage(Net::MessageIn &msg) override final;
-
         void talk(const std::string &restrict text,
                   const std::string &restrict channel) const override final;
 
@@ -61,9 +57,6 @@ class ChatHandler final : public MessageHandler, public Ea::ChatHandler
 
         void unIgnoreAll() const override final;
 
-        static void processRaw(MessageOut &restrict outMsg,
-                               const std::string &restrict line);
-
         void createChatRoom(const std::string &title,
                             const std::string &password,
                             const int limit,
@@ -97,21 +90,8 @@ class ChatHandler final : public MessageHandler, public Ea::ChatHandler
         void kickFromChatRoom(const std::string &nick) const override final;
 
     protected:
-        static void processChat(Net::MessageIn &msg);
-
-        static void processChatContinue(std::string chatMsg,
-                                        const std::string &channel);
-
-        static void processGmChat(Net::MessageIn &msg);
-
-        static void processWhisper(Net::MessageIn &msg);
-
-        static void processWhisperResponse(Net::MessageIn &msg);
-
-        static void processWhisperContinue(const std::string &nick,
-                                           std::string chatMsg);
-
-        static void processBeingChat(Net::MessageIn &msg);
+        static void processRaw(MessageOut &restrict outMsg,
+                               const std::string &restrict line);
 };
 
 }  // namespace TmwAthena
