@@ -25,12 +25,10 @@
 
 #include "net/ea/loginhandler.h"
 
-#include "net/tmwa/messagehandler.h"
-
 namespace TmwAthena
 {
 
-class LoginHandler final : public MessageHandler, public Ea::LoginHandler
+class LoginHandler final : public Ea::LoginHandler
 {
     public:
         LoginHandler();
@@ -39,8 +37,6 @@ class LoginHandler final : public MessageHandler, public Ea::LoginHandler
 
         ~LoginHandler();
 
-        void handleMessage(Net::MessageIn &msg) override final;
-
         void connect() override final;
 
         bool isConnected() const override final A_WARN_UNUSED;
@@ -69,10 +65,6 @@ class LoginHandler final : public MessageHandler, public Ea::LoginHandler
                                const std::string &restrict password,
                                const std::string &restrict email)
                                const override final;
-
-        static void processServerVersion(Net::MessageIn &msg);
-
-        static void processCharPasswordResponse(Net::MessageIn &msg);
 };
 
 }  // namespace TmwAthena
