@@ -22,23 +22,29 @@
 #ifndef RESOURCES_HORSEINFO_H
 #define RESOURCES_HORSEINFO_H
 
-#include "localconsts.h"
+#include "resources/spritereference.h"
 
-class AnimatedSprite;
+#include "localconsts.h"
 
 struct HorseInfo final
 {
     HorseInfo() :
-        sprite(nullptr),
-        offsetX(0),
-        offsetY(0)
+        downSprites(),
+        upSprites(),
+        downOffsetX(0),
+        downOffsetY(0),
+        upOffsetX(0),
+        upOffsetY(0)
     { }
 
     A_DELETE_COPY(HorseInfo)
 
-    AnimatedSprite *sprite;
-    int offsetX;
-    int offsetY;
+    std::vector<SpriteReference*> downSprites;
+    std::vector<SpriteReference*> upSprites;
+    int downOffsetX;
+    int downOffsetY;
+    int upOffsetX;
+    int upOffsetY;
 };
 
 #endif  // RESOURCES_HORSEINFO_H
