@@ -59,8 +59,11 @@ ItemInfo::ItemInfo() :
     mAnimationFiles(),
     mSounds(),
     mTags(),
-    mColors(nullptr),
-    mColorList(),
+    mColorsList(nullptr),
+    mIconColorsList(nullptr),
+    mColorsListName(),
+    mIconColorsListName(),
+    mCardColor(ItemColor_zero),
     mHitEffectId(-1),
     mCriticalHitEffectId(-1),
     mMissEffectId(-1),
@@ -191,48 +194,75 @@ void ItemInfo::setColorsList(const std::string &name)
 {
     if (name.empty())
     {
-        mColors = nullptr;
-        mColorList.clear();
+        mColorsList = nullptr;
+        mColorsListName.clear();
     }
     else
     {
-        mColors = ColorDB::getColorsList(name);
-        mColorList = name;
+        mColorsList = ColorDB::getColorsList(name);
+        mColorsListName = name;
     }
 }
 
-std::string ItemInfo::getDyeColorsString(const int color) const
+void ItemInfo::setIconColorsList(const std::string &name)
 {
-    if (!mColors || mColorList.empty())
+    if (name.empty())
+    {
+        mIconColorsList = nullptr;
+        mIconColorsListName.clear();
+    }
+    else
+    {
+        mIconColorsList = ColorDB::getColorsList(name);
+        mIconColorsListName = name;
+    }
+}
+
+std::string ItemInfo::getDyeColorsString(const ItemColor color) const
+{
+    if (!mColorsList || mColorsListName.empty())
         return "";
 
-    const std::map <int, ColorDB::ItemColor>::const_iterator
-        it = mColors->find(color);
-    if (it == mColors->end())
+    const std::map <ItemColor, ColorDB::ItemColorData>::const_iterator
+        it = mColorsList->find(color);
+    if (it == mColorsList->end())
         return "";
 
     return it->second.color;
 }
 
-const std::string ItemInfo::getDescription(const unsigned char color) const
+std::string ItemInfo::getDyeIconColorsString(const ItemColor color) const
+{
+    if (!mIconColorsList || mIconColorsListName.empty())
+        return "";
+
+    const std::map <ItemColor, ColorDB::ItemColorData>::const_iterator
+        it = mIconColorsList->find(color);
+    if (it == mIconColorsList->end())
+        return "";
+
+    return it->second.color;
+}
+
+const std::string ItemInfo::getDescription(const ItemColor color) const
 {
     return replaceColors(mDescription, color);
 }
 
-const std::string ItemInfo::getName(const unsigned char color) const
+const std::string ItemInfo::getName(const ItemColor color) const
 {
     return replaceColors(mName, color);
 }
 
 const std::string ItemInfo::replaceColors(std::string str,
-                                          const unsigned char color) const
+                                          const ItemColor color) const
 {
     std::string name;
-    if (mColors && !mColorList.empty())
+    if (mColorsList && !mColorsListName.empty())
     {
-        const std::map <int, ColorDB::ItemColor>::const_iterator
-            it = mColors->find(color);
-        if (it == mColors->end())
+        const std::map <ItemColor, ColorDB::ItemColorData>::const_iterator
+            it = mColorsList->find(color);
+        if (it == mColorsList->end())
             name = "unknown";
         else
             name = it->second.name;
@@ -369,26 +399,50 @@ void ItemInfo::setSprite(const std::string &animationFile,
     mAnimationFiles[static_cast<int>(gender) + race * 4] = animationFile;
 }
 
-std::string ItemInfo::getColorName(const int idx) const
+std::string ItemInfo::getColorName(const ItemColor idx) const
 {
-    if (!mColors)
+    if (!mColorsList)
         return std::string();
 
-    const std::map <int, ColorDB::ItemColor>::const_iterator
-        it = mColors->find(idx);
-    if (it == mColors->end())
+    const std::map <ItemColor, ColorDB::ItemColorData>::const_iterator
+        it = mColorsList->find(idx);
+    if (it == mColorsList->end())
         return std::string();
     return it->second.name;
 }
 
-std::string ItemInfo::getColor(const int idx) const
+std::string ItemInfo::getColor(const ItemColor idx) const
 {
-    if (!mColors)
+    if (!mColorsList)
         return std::string();
 
-    const std::map <int, ColorDB::ItemColor>::const_iterator
-        it = mColors->find(idx);
-    if (it == mColors->end())
+    const std::map <ItemColor, ColorDB::ItemColorData>::const_iterator
+        it = mColorsList->find(idx);
+    if (it == mColorsList->end())
+        return std::string();
+    return it->second.color;
+}
+
+std::string ItemInfo::getIconColorName(const ItemColor idx) const
+{
+    if (!mIconColorsList)
+        return std::string();
+
+    const std::map <ItemColor, ColorDB::ItemColorData>::const_iterator
+        it = mIconColorsList->find(idx);
+    if (it == mIconColorsList->end())
+        return std::string();
+    return it->second.name;
+}
+
+std::string ItemInfo::getIconColor(const ItemColor idx) const
+{
+    if (!mIconColorsList)
+        return std::string();
+
+    const std::map <ItemColor, ColorDB::ItemColorData>::const_iterator
+        it = mIconColorsList->find(idx);
+    if (it == mIconColorsList->end())
         return std::string();
     return it->second.color;
 }
