@@ -26,6 +26,7 @@
 #include "enums/being/gender.h"
 
 #include "enums/simpletypes/beingtypeid.h"
+#include "enums/simpletypes/itemcolor.h"
 
 #include "resources/cursor.h"
 #include "resources/itemtype.h"
@@ -34,7 +35,7 @@
 
 namespace ColorDB
 {
-    class ItemColor;
+    class ItemColorData;
 }
 
 // sprite, <itemfrom, itemto>
@@ -69,7 +70,7 @@ class ItemInfo final
         const std::string &getName() const A_WARN_UNUSED
         { return mName; }
 
-        const std::string getName(const unsigned char color)
+        const std::string getName(const ItemColor color)
                                   const A_WARN_UNUSED;
 
         void setDisplay(const SpriteDisplay &display)
@@ -84,7 +85,7 @@ class ItemInfo final
         const std::string &getDescription() const A_WARN_UNUSED
         { return mDescription; }
 
-        const std::string getDescription(const unsigned char color)
+        const std::string getDescription(const ItemColor color)
                                          const A_WARN_UNUSED;
 
         void setEffect(const std::string &effect)
@@ -227,6 +228,12 @@ class ItemInfo final
         int getPet() const
         { return mPet; }
 
+        void setCardColor(const ItemColor color)
+        { mCardColor = color; }
+
+        ItemColor getCardColor() const
+        { return mCardColor; }
+
         /** Effects to be shown when weapon attacks - see also effects.xml */
         std::string mMissileParticleFile;
 
@@ -238,15 +245,30 @@ class ItemInfo final
         const SpriteToItemMap *getSpriteToItemReplaceMap(const int directions)
                                                          const A_WARN_UNUSED;
 
-        std::string getDyeColorsString(const int color) const A_WARN_UNUSED;
+        std::string getDyeColorsString(const ItemColor color)
+                                       const A_WARN_UNUSED;
+
+        std::string getDyeIconColorsString(const ItemColor color)
+                                           const A_WARN_UNUSED;
 
         void setColorsList(const std::string &name);
 
+        void setIconColorsList(const std::string &name);
+
         bool isHaveColors() const A_WARN_UNUSED
-        { return !mColorList.empty(); }
+        { return !mColorsListName.empty(); }
+
+        bool isHaveIconColors() const A_WARN_UNUSED
+        { return !mIconColorsListName.empty(); }
+
+        std::string getColorsListName() const A_WARN_UNUSED
+        { return mColorsListName; }
+
+        std::string getIconColorsListName() const A_WARN_UNUSED
+        { return mIconColorsListName; }
 
         const std::string replaceColors(std::string str,
-                                        const unsigned char color)
+                                        const ItemColor color)
                                         const A_WARN_UNUSED;
 
         void setPickupCursor(const std::string &cursor)
@@ -265,11 +287,19 @@ class ItemInfo final
         { return mProtected; }
 
         int getColorsSize() const
-        { return mColors ? static_cast<int>(mColors->size()) : 0; }
+        { return mColorsList ? static_cast<int>(mColorsList->size()) : 0; }
 
-        std::string getColorName(const int idx) const;
+        int getIconColorsSize() const
+        {
+            return mIconColorsList ? static_cast<int>(mIconColorsList->size())
+                : 0;
+        }
 
-        std::string getColor(const int idx) const;
+        std::string getColorName(const ItemColor idx) const;
+        std::string getColor(const ItemColor idx) const;
+
+        std::string getIconColorName(const ItemColor idx) const;
+        std::string getIconColor(const ItemColor idx) const;
 
         int mDrawBefore[10];
         int mDrawAfter[10];
@@ -317,8 +347,11 @@ class ItemInfo final
         /** Stores the names of sounds to be played at certain event. */
         std::map <ItemSoundEvent::Type, SoundInfoVect> mSounds;
         std::map <int, int> mTags;
-        const std::map <int, ColorDB::ItemColor> *mColors;
-        std::string mColorList;
+        const std::map <ItemColor, ColorDB::ItemColorData> *mColorsList;
+        const std::map <ItemColor, ColorDB::ItemColorData> *mIconColorsList;
+        std::string mColorsListName;
+        std::string mIconColorsListName;
+        ItemColor mCardColor;
         int mHitEffectId;
         int mCriticalHitEffectId;
         int mMissEffectId;
