@@ -147,14 +147,6 @@ Map::Map(const int width, const int height,
     mCustom(false),
     mDrawOnlyFringe(false)
 {
-    const int size = mWidth * mHeight;
-    for (int i = 0; i < BlockType::NB_BLOCKTYPES; i++)
-    {
-        mOccupation[i] = new unsigned[static_cast<size_t>(size)];
-        memset(mOccupation[i], 0, static_cast<size_t>(size)
-            * sizeof(unsigned));
-    }
-
     config.addListener("OverlayDetail", this);
     config.addListener("guialpha", this);
     config.addListener("beingopacity", this);
@@ -171,8 +163,6 @@ Map::~Map()
     CHECKLISTENERS
 
     delete [] mMetaTiles;
-    for (int i = 0; i < BlockType::NB_BLOCKTYPES; i++)
-        delete [] mOccupation[i];
 
     if (mWalkLayer)
     {
@@ -689,46 +679,69 @@ const Tileset *Map::getTilesetWithGid(const int gid) const
         return nullptr;
 }
 
-void Map::blockTile(const int x, const int y,
-                    const BlockType::BlockType type)
+void Map::addBlockMask(const int x, const int y,
+                       const BlockTypeT type)
 {
     if (type == BlockType::NONE || !contains(x, y))
         return;
 
     const int tileNum = x + y * mWidth;
 
-    if (mOccupation[static_cast<size_t>(type)][tileNum] < UINT_MAX &&
-        (++mOccupation[static_cast<size_t>(type)][tileNum]) > 0)
+    switch (type)
     {
-        switch (type)
-        {
-            case BlockType::WALL:
-                mMetaTiles[tileNum].blockmask |= BlockMask::WALL;
-                break;
-            case BlockType::CHARACTER:
-                mMetaTiles[tileNum].blockmask |= BlockMask::CHARACTER;
-                break;
-            case BlockType::MONSTER:
-                mMetaTiles[tileNum].blockmask |= BlockMask::MONSTER;
-                break;
-            case BlockType::AIR:
-                mMetaTiles[tileNum].blockmask |= BlockMask::AIR;
-                break;
-            case BlockType::WATER:
-                mMetaTiles[tileNum].blockmask |= BlockMask::WATER;
-                break;
-            case BlockType::GROUND:
-                mMetaTiles[tileNum].blockmask |= BlockMask::GROUND;
-                break;
-            case BlockType::GROUNDTOP:
-                mMetaTiles[tileNum].blockmask |= BlockMask::GROUNDTOP;
-                break;
-            default:
-            case BlockType::NONE:
-            case BlockType::NB_BLOCKTYPES:
-                // Do nothing.
-                break;
-        }
+        case BlockType::WALL:
+            mMetaTiles[tileNum].blockmask |= BlockMask::WALL;
+            break;
+        case BlockType::AIR:
+            mMetaTiles[tileNum].blockmask |= BlockMask::AIR;
+            break;
+        case BlockType::WATER:
+            mMetaTiles[tileNum].blockmask |= BlockMask::WATER;
+            break;
+        case BlockType::GROUND:
+            mMetaTiles[tileNum].blockmask |= BlockMask::GROUND;
+            break;
+        case BlockType::GROUNDTOP:
+            mMetaTiles[tileNum].blockmask |= BlockMask::GROUNDTOP;
+            break;
+        default:
+        case BlockType::NONE:
+        case BlockType::NB_BLOCKTYPES:
+            // Do nothing.
+            break;
+    }
+}
+
+void Map::setBlockMask(const int x, const int y,
+                       const BlockTypeT type)
+{
+    if (type == BlockType::NONE || !contains(x, y))
+        return;
+
+    const int tileNum = x + y * mWidth;
+
+    switch (type)
+    {
+        case BlockType::WALL:
+            mMetaTiles[tileNum].blockmask = BlockMask::WALL;
+            break;
+        case BlockType::AIR:
+            mMetaTiles[tileNum].blockmask = BlockMask::AIR;
+            break;
+        case BlockType::WATER:
+            mMetaTiles[tileNum].blockmask = BlockMask::WATER;
+            break;
+        case BlockType::GROUND:
+            mMetaTiles[tileNum].blockmask = BlockMask::GROUND;
+            break;
+        case BlockType::GROUNDTOP:
+            mMetaTiles[tileNum].blockmask = BlockMask::GROUNDTOP;
+            break;
+        default:
+        case BlockType::NONE:
+        case BlockType::NB_BLOCKTYPES:
+            // Do nothing.
+            break;
     }
 }
 
@@ -753,9 +766,9 @@ unsigned char Map::getBlockMask(const int x, const int y) const
     return mMetaTiles[x + y * mWidth].blockmask;
 }
 
-void Map::setWalk(const int x, const int y, const bool walkable A_UNUSED)
+void Map::setWalk(const int x, const int y)
 {
-    blockTile(x, y, BlockType::GROUNDTOP);
+    addBlockMask(x, y, BlockType::GROUNDTOP);
 }
 
 bool Map::contains(const int x, const int y) const
@@ -801,6 +814,14 @@ const std::string Map::getFilename() const
     return fileName.substr(lastSlash, fileName.rfind(".") - lastSlash);
 }
 
+const std::string Map::getGatName() const
+{
+    const std::string fileName = getProperty("_filename");
+    const size_t lastSlash = fileName.rfind("/") + 1;
+    return fileName.substr(lastSlash,
+        fileName.rfind(".") - lastSlash).append(".gat");
+}
+
 Path Map::findPath(const int startX, const int startY,
                    const int destX, const int destY,
                    const unsigned char blockWalkMask,
@@ -1405,7 +1426,7 @@ void Map::reduce()
                 if (x >= layer->mWidth || y >= layer->mHeight)
                     continue;
 
-                Image *const img = layer->mTiles[x + y * layer->mWidth];
+                Image *const img = layer->mTiles[x + y * layer->mWidth].image;
                 if (img)
                 {
                     if (img->hasAlphaChannel() && img->isAlphaCalculated())
@@ -1487,7 +1508,7 @@ void Map::reduce()
                     continue;
                 }
 
-                const Image *img = layer->mTiles[x + y * layer->mWidth];
+                const Image *img = layer->mTiles[x + y * layer->mWidth].image;
                 if (img && !img->isAlphaVisible())
                 {   // removing all down tiles
                     ++ ri;
@@ -1496,10 +1517,10 @@ void Map::reduce()
                         MapLayer *const layer2 = *ri;
                         const size_t pos = static_cast<size_t>(
                             x + y * layer2->mWidth);
-                        img = layer2->mTiles[pos];
+                        img = layer2->mTiles[pos].image;
                         if (img)
                         {
-                            layer2->mTiles[pos] = nullptr;
+                            layer2->mTiles[pos].image = nullptr;
                             cnt ++;
                         }
                         ++ ri;
@@ -1624,3 +1645,17 @@ void Map::setActorsFix(const int x, const int y)
     if (mFringeLayer)
         mFringeLayer->setActorsFix(y);
 }
+
+void Map::updateConditionLayers()
+{
+    mRedrawMap = true;
+
+    FOR_EACH (LayersCIter, it, mLayers)
+    {
+        MapLayer *const layer = *it;
+        if (!layer || layer->mTileCondition == -1)
+            continue;
+        layer->updateConditionTiles(mMetaTiles,
+            mWidth, mHeight);
+    }
+}
