@@ -142,11 +142,11 @@ class Map final : public Properties, public ConfigListener
         const MetaTile *getMetaTile(const int x,
                                     const int y) const A_WARN_UNUSED;
 
-        /**
-         * Marks a tile as occupied.
-         */
-        void blockTile(const int x, const int y,
-                       const BlockType::BlockType type);
+        void addBlockMask(const int x, const int y,
+                          const BlockTypeT type);
+
+        void setBlockMask(const int x, const int y,
+                          const BlockTypeT type);
 
         /**
          * Gets walkability for a tile with a blocking bitmask. When called
@@ -156,7 +156,7 @@ class Map final : public Properties, public ConfigListener
                      const unsigned char blockWalkMask = BlockMask::WALL
                      | BlockMask::AIR | BlockMask::WATER) const A_WARN_UNUSED;
 
-        void setWalk(const int x, const int y, const bool walkable);
+        void setWalk(const int x, const int y);
 
         unsigned char getBlockMask(const int x, const int y) const;
 
@@ -195,6 +195,8 @@ class Map final : public Properties, public ConfigListener
          */
         const std::string getFilename() const A_WARN_UNUSED;
 
+        const std::string getGatName() const A_WARN_UNUSED;
+
         /**
          * Find a path from one location to the next.
          */
@@ -337,6 +339,8 @@ class Map final : public Properties, public ConfigListener
         bool isHeightsPresent() const
         { return mHeights != nullptr; }
 
+        void updateConditionLayers();
+
     protected:
         friend class Actor;
         friend class Minimap;
@@ -375,11 +379,6 @@ class Map final : public Properties, public ConfigListener
          */
         bool contains(const int x, const int y) const A_WARN_UNUSED;
 
-        /**
-         * Blockmasks for different entities
-         */
-        unsigned *mOccupation[BlockType::NB_BLOCKTYPES];
-
         const int mWidth;
         const int mHeight;
         const int mTileWidth;
