@@ -30,6 +30,7 @@
 
 #include "being/localplayer.h"
 
+#include "enums/resources/map/blockmask.h"
 #include "enums/resources/map/mapitemtype.h"
 
 #include "gui/userpalette.h"
@@ -40,6 +41,7 @@
 
 #include "resources/map/mapitem.h"
 #include "resources/map/maprowvertexes.h"
+#include "resources/map/metatile.h"
 #include "resources/map/speciallayer.h"
 
 #include "debug.h"
@@ -47,23 +49,25 @@
 MapLayer::MapLayer(const int x, const int y,
                    const int width, const int height,
                    const bool fringeLayer,
-                   const int mask) :
+                   const int mask,
+                   const int tileCondition) :
     mX(x),
     mY(y),
     mWidth(width),
     mHeight(height),
-    mTiles(new Image*[mWidth * mHeight]),
+    mTiles(new TileInfo[mWidth * mHeight]),
     mDrawLayerFlags(MapType::NORMAL),
     mSpecialLayer(nullptr),
     mTempLayer(nullptr),
     mTempRows(),
     mMask(mask),
+    mTileCondition(tileCondition),
     mActorsFix(0),
     mIsFringeLayer(fringeLayer),
     mHighlightAttackRange(config.getBoolValue("highlightAttackRange")),
     mSpecialFlag(true)
 {
-    std::fill_n(mTiles, mWidth * mHeight, static_cast<Image*>(nullptr));
+//    std::fill_n(mTiles, mWidth * mHeight, static_cast<Image*>(nullptr));
 
     config.addListener("highlightAttackRange", this);
 }
@@ -72,7 +76,10 @@ MapLayer::~MapLayer()
 {
     config.removeListener("highlightAttackRange", this);
     CHECKLISTENERS
-    delete [] mTiles;
+//    const int sz = mWidth * mHeight;
+//    for (int f = 0; f < sz; f ++)
+//        delete mTiles[f].image;
+    delete []mTiles;
     delete_all(mTempRows);
     mTempRows.clear();
 }
@@ -88,7 +95,7 @@ void MapLayer::optionChanged(const std::string &value)
 
 void MapLayer::setTile(const int x, const int y, Image *const img)
 {
-    mTiles[x + y * mWidth] = img;
+    mTiles[x + y * mWidth].image = img;
 }
 
 void MapLayer::draw(Graphics *const graphics,
@@ -123,14 +130,16 @@ void MapLayer::draw(Graphics *const graphics,
 
         const int py0 = y32 + dy;
 
-        Image **tilePtr = mTiles + static_cast<size_t>(startX + yWidth);
+        TileInfo *tilePtr = &mTiles[static_cast<size_t>(startX + yWidth)];
 
         for (int x = startX; x < endX; x++, tilePtr++)
         {
+            if (!tilePtr->isEnabled)
+                continue;
             const int x32 = x * mapTileSize;
 
             int c = 0;
-            const Image *const img = *tilePtr;
+            const Image *const img = tilePtr->image;
             if (img)
             {
                 const int px = x32 + dx;
@@ -139,7 +148,7 @@ void MapLayer::draw(Graphics *const graphics,
                 {
                     int width = 0;
                     // here need not draw over player position
-                    c = getTileDrawWidth(img, endX - x, width);
+                    c = getTileDrawWidth(tilePtr, endX - x, width);
 
                     if (!c)
                     {
@@ -154,6 +163,7 @@ void MapLayer::draw(Graphics *const graphics,
             }
 
             x += c;
+            tilePtr += c;
         }
     }
     BLOCK_END("MapLayer::draw")
@@ -216,11 +226,13 @@ void MapLayer::updateSDL(const Graphics *const graphics,
 
         const int yWidth = y * mWidth;
         const int py0 = y * mapTileSize + dy;
-        Image **tilePtr = mTiles + static_cast<size_t>(startX + yWidth);
+        TileInfo *tilePtr = &mTiles[static_cast<size_t>(startX + yWidth)];
 
         for (int x = startX; x < endX; x++, tilePtr++)
         {
-            Image *const img = *tilePtr;
+            if (!tilePtr->isEnabled)
+                continue;
+            Image *const img = (*tilePtr).image;
             if (img)
             {
                 const int px = x * mapTileSize + dx;
@@ -279,10 +291,12 @@ void MapLayer::updateOGL(Graphics *const graphics,
     {
         const int yWidth = y * mWidth;
         const int py0 = y * mapTileSize + dy;
-        Image **tilePtr = mTiles + static_cast<size_t>(startX + yWidth);
+        TileInfo *tilePtr = &mTiles[static_cast<size_t>(startX + yWidth)];
         for (int x = startX; x < endX; x++, tilePtr++)
         {
-            Image *const img = *tilePtr;
+            if (!tilePtr->isEnabled)
+                continue;
+            Image *const img = (*tilePtr).image;
             if (img)
             {
                 const int px = x * mapTileSize + dx;
@@ -480,14 +494,16 @@ void MapLayer::drawFringe(Graphics *const graphics,
             const int py0 = y32 + dy;
             const int py1 = y32 - scrollY;
 
-            Image **tilePtr = mTiles + static_cast<size_t>(startX + yWidth);
+            TileInfo *tilePtr = &mTiles[static_cast<size_t>(startX + yWidth)];
             for (int x = startX; x < endX; x++, tilePtr++)
             {
+                if (!tilePtr->isEnabled)
+                    continue;
                 const int x32 = x * mapTileSize;
 
                 const int px1 = x32 - scrollX;
                 int c = 0;
-                const Image *const img = *tilePtr;
+                const Image *const img = tilePtr->image;
                 if (img)
                 {
                     if (mSpecialFlag || img->mBounds.h <= mapTileSize)
@@ -496,7 +512,7 @@ void MapLayer::drawFringe(Graphics *const graphics,
                         const int py = py0 - img->mBounds.h;
                         int width = 0;
                         // here need not draw over player position
-                        c = getTileDrawWidth(img, endX - x, width);
+                        c = getTileDrawWidth(tilePtr, endX - x, width);
 
                         if (!c)
                         {
@@ -544,6 +560,7 @@ void MapLayer::drawFringe(Graphics *const graphics,
                     }
                 }
                 x += c;
+                tilePtr += c;
             }
         }
 
@@ -565,11 +582,13 @@ void MapLayer::drawFringe(Graphics *const graphics,
 
             const int py0 = y32 + dy;
 
-            Image **tilePtr = mTiles + static_cast<size_t>(startX + yWidth);
+            TileInfo *tilePtr = &mTiles[static_cast<size_t>(startX + yWidth)];
             for (int x = startX; x < endX; x++, tilePtr++)
             {
+                if (!tilePtr->isEnabled)
+                    continue;
                 const int x32 = x * mapTileSize;
-                const Image *const img = *tilePtr;
+                const Image *const img = tilePtr->image;
                 if (img)
                 {
                     const int px = x32 + dx;
@@ -578,7 +597,9 @@ void MapLayer::drawFringe(Graphics *const graphics,
                     {
                         int width = 0;
                         // here need not draw over player position
-                        const int c = getTileDrawWidth(img, endX - x, width);
+                        const int c = getTileDrawWidth(tilePtr,
+                            endX - x,
+                            width);
 
                         if (!c)
                         {
@@ -589,6 +610,7 @@ void MapLayer::drawFringe(Graphics *const graphics,
                             graphics->drawPattern(img, px, py,
                                 width, img->mBounds.h);
                             x += c;
+                            tilePtr += c;
                         }
                     }
                 }
@@ -641,12 +663,12 @@ void MapLayer::drawFringe(Graphics *const graphics,
     BLOCK_END("MapLayer::drawFringe")
 }
 
-int MapLayer::getTileDrawWidth(const Image *img,
+int MapLayer::getTileDrawWidth(const TileInfo *tilePtr,
                                const int endX,
                                int &width)
 {
     BLOCK_START("MapLayer::getTileDrawWidth")
-    const Image *const img1 = img;
+    const Image *const img1 = tilePtr->image;
     int c = 0;
     if (!img1)
     {
@@ -657,8 +679,9 @@ int MapLayer::getTileDrawWidth(const Image *img,
     width = img1->mBounds.w;
     for (int x = 1; x < endX; x++)
     {
-        img ++;
-        if (img != img1)
+        tilePtr ++;
+        const Image *const img = tilePtr->image;
+        if (img != img1 || !tilePtr->isEnabled)
             break;
         c ++;
         if (img)
@@ -675,3 +698,29 @@ void MapLayer::setDrawLayerFlags(const MapTypeT &n)
         && mDrawLayerFlags != MapType::SPECIAL2
         && mDrawLayerFlags != MapType::SPECIAL4);
 }
+
+void MapLayer::updateConditionTiles(MetaTile *const metaTiles,
+                                    const int width, const int height)
+{
+    const int width1 = width < mWidth ? width : mWidth;
+    const int height1 = height < mHeight ? height : mHeight;
+
+    for (int y = mY; y < height1; y ++)
+    {
+        MetaTile *metaPtr = metaTiles + (y - mY) * width;
+        TileInfo *tilePtr = mTiles + y * mWidth;
+        for (int x = mX; x < width1; x ++, metaPtr ++, tilePtr ++)
+        {
+            if (metaPtr->blockmask & mTileCondition ||
+                (metaPtr->blockmask == 0 &&
+                mTileCondition == BlockMask::GROUND))
+            {
+                tilePtr->isEnabled = true;
+            }
+            else
+            {
+                tilePtr->isEnabled = false;
+            }
+        }
+    }
+}
