@@ -219,12 +219,6 @@ class ResourceManager final
 
         void clearScheduled();
 
-        /**
-         * Returns an instance of the class, creating one if it does not
-         * already exist.
-         */
-        static ResourceManager *getInstance() RETURNS_NONNULL A_WARN_UNUSED;
-
         /**
          * Deletes the class instance if it exists.
          */
@@ -255,6 +249,8 @@ class ResourceManager final
 
         void clearCache();
 
+        static void init();
+
     private:
         /**
          * Deletes the resource after logging a cleanup message.
@@ -273,4 +269,6 @@ class ResourceManager final
         bool mUseLongLiveSprites;
 };
 
+extern ResourceManager *resourceManager;
+
 #endif  // RESOURCES_RESOURCEMANAGER_H
