@@ -25,7 +25,9 @@
 #include "configuration.h"
 #include "logger.h"
 
+#ifndef DYECMD
 #include "being/localplayer.h"
+#endif
 
 #include "resources/sdlmusic.h"
 #include "resources/resourcemanager.h"
@@ -253,8 +255,8 @@ void SoundManager::setSfxVolume(const int volume)
 
 static SDLMusic *loadMusic(const std::string &fileName)
 {
-    ResourceManager *const resman = ResourceManager::getInstance();
-    return resman->getMusic(paths.getStringValue("music").append(fileName));
+    return resourceManager->getMusic(
+        paths.getStringValue("music").append(fileName));
 }
 
 void SoundManager::playMusic(const std::string &fileName)
@@ -358,6 +360,13 @@ void SoundManager::logic()
     BLOCK_END("SoundManager::logic")
 }
 
+#ifdef DYECMD
+void SoundManager::playSfx(const std::string &path A_UNUSED,
+                           const int x A_UNUSED,
+                           const int y A_UNUSED) const
+{
+}
+#else
 void SoundManager::playSfx(const std::string &path,
                            const int x, const int y) const
 {
@@ -369,8 +378,7 @@ void SoundManager::playSfx(const std::string &path,
         tmpPath = path;
     else
         tmpPath = paths.getValue("sfx", "sfx/").append(path);
-    ResourceManager *const resman = ResourceManager::getInstance();
-    SoundEffect *const sample = resman->getSoundEffect(tmpPath);
+    SoundEffect *const sample = resourceManager->getSoundEffect(tmpPath);
     if (sample)
     {
         logger->log("SoundManager::playSfx() Playing: %s", path.c_str());
@@ -394,6 +402,7 @@ void SoundManager::playSfx(const std::string &path,
             sample->decRef();
     }
 }
+#endif
 
 void SoundManager::playGuiSound(const std::string &name)
 {
@@ -411,8 +420,7 @@ void SoundManager::playGuiSfx(const std::string &path)
         tmpPath = path;
     else
         tmpPath = paths.getValue("sfx", "sfx/").append(path);
-    ResourceManager *const resman = ResourceManager::getInstance();
-    SoundEffect *const sample = resman->getSoundEffect(tmpPath);
+    SoundEffect *const sample = resourceManager->getSoundEffect(tmpPath);
     if (sample)
     {
         logger->log("SoundManager::playGuiSfx() Playing: %s", path.c_str());
